@@ -19,12 +19,17 @@ service corosync start
 service pacemaker start
 sleep $DAEMON_TIMEOUT
 
-POS="$(corosync-cmapctl -q -g nodelist.local_node_pos)"
 # Get the node name as sugested in
 # https://lists.clusterlabs.org/pipermail/users/2022-May/030309.html
 NODE="$(crm_node -n)"
-IP="$(corosync-cmapctl -q -g nodelist.node.$POS.ring0_addr)"
-echo "$IP $NODE" >> /etc/hosts
+if [ -z "$NODE" ]; then
+  echo "Could not detect node name"
+  exit 1
+fi
+# crmsh will try to ping the node name so make sure it can be resolved
+if ! getent hosts "$NODE" >/dev/null 2>&1; then
+  echo "127.0.0.1 $NODE" >> /etc/hosts
+fi
 
 #
 # online
